<?php

class ImageGalleryAlbum extends DataObject
{
	static $db = array (
		'Title' => 'Varchar(100)',
		'Description' => 'Text',
		'Slug' => 'Text',
		'Source' => "Enum('new, existing')",
	);
	
	static $has_one = array (
		'Folder' => 'Folder',
		'CoverImage' => 'Image',
		'ImageGalleryPage' => 'ImageGalleryPage'
	);
	
	static $has_many = array (
		'Images' => 'ImageGalleryFile'
	);
	
	static $defaults = array (
		'Source' => 'new'
	);
	
	private static function cleanURL($string)
	{
		$string = strtolower(str_replace(" ","-",$string));
		return ereg_replace("[^A-Za-z0-9-]", "", $string);
	}
	
	public function Link()
	{
		return $this->ImageGalleryPage()->Link('album/'.$this->Slug);
	}
	
	public function LinkingMode()
	{
		return Director::urlParam('ID') == $this->Slug ? 'current' : 'link';
	}
	
	public function getCMSFields_forPopup()
	{
		$f = new FieldSet();
		$f->push(new TextField('Title'));
		$f->push(new TextareaField('Description','Description'));
		if(!$this->FolderID) {
			$f->push(new PopupSelectionGroup("Source", array(
						"new//Create a new folder" => new HiddenField(""),
						"existing//Use an existing folder" => new FieldGroup("",
							new DropdownField("FolderID","",DataObject::get("Folder",null,"Title ASC")->toDropdownMap('ID','Filename'))
						)
					))
			);
		}
		else {
			$f->push(new DropdownField("FolderID","Folder",DataObject::get("Folder",null,"Title ASC")->toDropdownMap('ID','Filename')));
		}
		$f->push(new ImageField('CoverImage','Cover Image'));
		
		return $f;
	}
	
	public function FormattedCoverImage()
	{
		return $this->CoverImage()->CroppedImage($this->ImageGalleryPage()->CoverImageWidth,$this->ImageGalleryPage()->CoverImageHeight);
	}
	function onBeforeWrite()
	{
		parent::onBeforeWrite();
		
		// To help keep things straight, we'll create a unique "slug" (similar to a URLSegment)
		// that is guaranteed to be unique. The "Name" property of a folder is not.
		
		if(isset($_POST['Title']) && !empty($_POST['Title'])) {
			$clean_url = self::cleanURL($_POST['Title']);
			// Make sure it's unique!
			$test_url = $clean_url;
			$i = 1;
			while(DataObject::get_one("ImageGalleryAlbum","Slug = '$test_url' AND ImageGalleryPageID = {$this->ImageGalleryPageID} AND ImageGalleryAlbum.ID != {$this->ID}")) {
				$test_url = $clean_url . "-" . $i;
				$i++;
			}
			$this->Slug = $test_url;
		}
			
		if(isset($_POST['Source']) && $_POST['Source'] == "new" && $this->Slug) {
			$parent = DataObject::get_by_id("ImageGalleryPage",$this->ImageGalleryPageID);
			if($parent->RootFolderID) {
				$root = $parent->RootFolder();
				$folder = Folder::findOrMake($root->Filename . $this->Slug);
				$folder->Title = $_POST['Title'];
				$folder->write();
				$this->FolderID = $folder->ID;
			}
			else {
				$this->FolderID = 0;
			}
		}
	}
	
}


?>